#!/bin/sh
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# Copyright IBM Corporation 2015, 2016. All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

usage() {
    echo -e -n "\n"
    echo "syncExistingUsers.sh [options...]"
    echo -e -n "\n"
    echo "Options:"
    echo "    -?, -help                             Print this message"
    echo "    -u <username>, -username <username>   User name of admin user"
    echo "    -p <password>, -password <password>   User password (unencrypted)"
    echo "    -host                                 Server host name, must be used with port"
    echo "    -port                                 Server SOAP port number"
    echo "    -userState sync                       Activate users in the BPM database who are in the user"
    echo "                                          registry and deactivate users in the database who are"
    echo "                                          no longer in the user registry. If you omit the 'sync'"
    echo "                                          parameter or use any other value, nothing is updated."
    echo -e -n "\n"
    exit $1
}

USERNAME_ARG=
PASSWORD_ARG=
USER_INSTALL_ROOT=
HOSTNAME=
SERVERPORT=
USERSTATE=none

FINISHED='0'
until [ "$#" = "0" -o $FINISHED = '1' ]
do
    case "$1" in
        '-help'|'-?')
            usage 0
            ;;
        '-USER_INSTALL_ROOT')
            USER_INSTALL_ROOT="$2"
            shift;shift
            ;;
        '-username'|'-u'|'-user')
            USERNAME_ARG="-user $2"
            shift;shift
            ;;
        '-password'|'-p')
            PASSWORD_ARG="-password $2"
            shift;shift
            ;;
        '-host')
            HOSTNAME="-host $2"
            shift;shift
            ;;
        '-port')
            SERVERPORT="-port $2"
            shift;shift
            ;;
        '-userState')
            USERSTATE="$2"
            shift;shift
            ;;
        *)
            if [ "$1" ]
            then
               usage 1
            fi
            FINISHED='1'
            ;;
    esac
done

if [ ! "$USER_INSTALL_ROOT" ]
then
    echo "WARNING: Execute script from profile's 'bin' directory."
fi

if [ -n "$HOSTNAME" ]
then

     $USER_INSTALL_ROOT/bin/wsadmin.sh -lang jython -wsadmin_classpath $WAS_HOME"/BPM/Lombardi/lib/ps.jar":$WAS_HOME"/BPM/Lombardi/lib/utility.jar" $USERNAME_ARG $PASSWORD_ARG -conntype SOAP $HOSTNAME $SERVERPORT -f $WAS_HOME"/BPM/Lombardi/tools/security/syncExistingUsers.jy" -userState $USERSTATE

else

     $USER_INSTALL_ROOT/bin/wsadmin.sh -lang jython -wsadmin_classpath $WAS_HOME"/BPM/Lombardi/lib/ps.jar":$WAS_HOME"/BPM/Lombardi/lib/utility.jar" $USERNAME_ARG $PASSWORD_ARG -f $WAS_HOME"/BPM/Lombardi/tools/security/syncExistingUsers.jy" -userState $USERSTATE

fi


if [ "$?" -ne "0" ]
then
    echo "Failed, see logs for further details."
    echo -e -n "\n"
    exit $?
fi
